@@ -7,6 +7,7 @@ from starlite.utils import AsyncCallable, normalize_path
 if TYPE_CHECKING:
     from pydantic_openapi_schema.v3_1_0 import SecurityRequirement
 
+    from starlite.datastructures import CacheControlHeader, ETag
     from starlite.router import Router
     from starlite.types import (
         AfterRequestHookHandler,
@@ -35,6 +36,7 @@ class Controller:
         "after_response",
         "before_request",
         "dependencies",
+        "etag",
         "exception_handlers",
         "guards",
         "middleware",
@@ -64,10 +66,20 @@ class Controller:
         It receives the [Request][starlite.connection.Request] instance and any
         non-`None` return value is used for the response, bypassing the route handler.
     """
+    cache_control: Optional["CacheControlHeader"]
+    """
+         A [CacheControlHeader][starlite.datastructures.CacheControlHeader] header to add to route handlers
+         of this controller. Can be overridden by route handlers.
+    """
     dependencies: Optional["Dependencies"]
     """
         dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
     """
+    etag: Optional["ETag"]
+    """
+        An `etag` header of type [ETag][starlite.datastructures.ETag] to add to route handlers of this controller.
+        Can be overridden by route handlers.
+    """
     exception_handlers: Optional["ExceptionHandlersMap"]
     """
         A dictionary that maps handler functions to status codes and/or exception types.
