@@ -1,6 +1,7 @@
 from starlite.datastructures.background_tasks import BackgroundTask, BackgroundTasks
 from starlite.datastructures.cookie import Cookie
 from starlite.datastructures.form_multi_dict import FormMultiDict
+from starlite.datastructures.headers import CacheControlHeader, ETag
 from starlite.datastructures.provide import Provide
 from starlite.datastructures.response_containers import (
     File,
@@ -17,6 +18,8 @@ __all__ = (
     "BackgroundTask",
     "BackgroundTasks",
     "Cookie",
+    "CacheControlHeader",
+    "ETag",
     "File",
     "FormMultiDict",
     "Provide",
