@@ -171,7 +171,7 @@ class Router:
                 if existing_handlers:
                     route_handlers.extend(unique(existing_handlers))
                     existing_route_index = find_index(
-                        self.routes, lambda x: x.path == path  # pylint: disable=cell-var-from-loop
+                        self.routes, lambda x: x.path == path  # pylint: disable=cell-var-from-loop # noqa: B023
                     )
 
                     if existing_route_index == -1:  # pragma: no cover
